#!/bin/csh -f

echo " "
echo "prepare_fpt_build_environment.csh"
echo " "
if (! -e fpt_build_environment) then
	echo "This script must be run from the parent directory containing"
	echo "fpt_build_environment.  Aborting"
	echo " "
	exit
endif

if (($1 != "WRFV3.4.1") && ($1 != "WRFV3.6.1")) then
	echo "Usage: prepare_fpt_build_environment WRF_version [ s ]"
	echo " "
	echo "Where WRF_version is WRFV3.4.1 or WRFV3.6.1 and s indicates silent"
	echo " "
	exit
endif 

# Copy the UCAR_not_built directory structure to the build area so that all of the
# Makefiles and c files are the right versions and in the right places
cd fpt_build_environment
../tools/clean_all_fortran.csh $2
cp -R ../UCAR_not_built_$1/WRFV3 .
cd ..

# copy .h files generated in the fpt pass.  This is done first so that any which are
# normally present and shared with C are overwritten by copying from the clean build
# directories.
tools/copy_wrf_files.csh \*.h    fpt_output fpt_build_environment s

# set up the default .h files from the clean build.  There is no need to copy *.F90
# fpt makes all those that are needed.  Note that nearly all the .F and .inc
# files will be overwritten, but the fpt pass only processes files for wrf.exe
# and does not create the sources for diffwrf or ideal.exe
tools/copy_wrf_files.csh \*.h   UCAR_clean_build_$1 fpt_build_environment s
# check that everything is writable, so that we can overwrite them
cd fpt_build_environment
chmod -R o+rw *
cd .. 

# copy in the post-FPT files
# note that we do NOT copy *.h at this point because fpt inserts Fortran comments and
# some *.h files are shared with c.
tools/copy_wrf_files.csh \*.F    fpt_output fpt_build_environment s
tools/copy_wrf_files.csh \*.F90  fpt_output fpt_build_environment s
tools/copy_wrf_files.csh \*.for  fpt_output fpt_build_environment s
tools/copy_wrf_files.csh \*.inc  fpt_output fpt_build_environment s
tools/copy_wrf_files.csh \*.int  fpt_output fpt_build_environment s
tools/copy_wrf_files.csh \*.code fpt_output fpt_build_environment s
tools/copy_wrf_files.csh \*.f90  fpt_output fpt_build_environment s

# copy in the makefiles and build files which differ from the UCAR build
tools/copy_wrf_files.csh \* modified_build_files_$1 fpt_build_environment s


# copy one include file which is in the wrong directory
if ("$1" == "WRFV3.4.1") then
   cp fpt_build_environment/WRFV3/dyn_em/namelist_remappings_em.h fpt_build_environment/WRFV3/inc/
endif
echo " "
echo "End of prepare_fpt_build_environment.csh"
echo " "

# End of prepare_fpt_build_environment.csh

