#!/bin/csh -f

echo " "
echo "setup_WRFV3_fpt_test_environment.csh"
echo "===================================="
echo " "
echo "This is version 2.0 of this file, dated 18-Dec-14."
echo " "
if (("$1" != "WRFV3.4.1") && ("$1" != "WRFV3.6.1")) then
	echo "Usage:"
	echo "$ tools/setup_WRFV3_fpt_test_environment WRFV3_version [s]"
	echo " "
	echo "Where WRFV3_version is currently WRFV3.4.1 or WRFV3.6.1"
	echo "and the optional argument s requests running silently without prompting."
	echo " "
	exit
endif

setenv BASE_DIR `pwd`

if (! -e $1.TAR.gz) then
	echo "This script must be run from the parent directory containing"
	echo "$1.TAR.gz.  Aborting"
	echo " "
	exit
endif

if ("$1" == "WRFV3.6.1") then
	if (! -e mediation_feedback_domain.F.fix-3.6.1) then
		echo "The serial build of WRFV3.6.1 in this setup requires the fix published by"
	        echo "UCAR at http://www2.mmm.ucar.edu/wrf/users/wrfv3.6/known-prob-3.6.1.html"
	        echo "Select the note on \"Building WRF Serially\" and download the file"
	        echo "mediation_feedback_domain.F.fix-3.6.1 to this directory.  Then run the"
		echo "setup script again"
	 	echo " "
		exit
	endif
endif

if (! $?NETCDF) then
	echo "This script will attempt a build of $1."
	echo "The build requires NetCDF to be installed, and the symbol NETCDF to"
	echo "be defined as the main installation directory, so that the libraries"
	echo "reside in NETCDF/lib"
	echo " "
	echo "If NetCDF is not installed, please refer to"
	echo "https://www.unidata.ucar.edu/netcdf/dics/netcdf-install"
	echo "Install NetCDF and then repeat this setup"
	echo " "
	exit
endif

# Copying netcdf.inc to inc to make it visible to fpt
cp $NETCDF/include/netcdf.inc modified_source_minimal_$1/WRFV3/inc/

echo " "
echo "Creating UCAR_not_built_$1 - a clean installation for file comparison"
if ( $2 != 's') then
	echo -n "Continue? [y|n]: "
	set REQ = $<
	if (($REQ != 'y') && ($REQ != 'Y')) then
		echo "Aborted"
		exit
	endif
endif
echo "Continuing"
echo " "
if (-e UCAR_not_built_$1) then
	echo "Deleting existing UCAR_not_built directory structure"
	if ( $2 != 's') then	
		echo -n "Continue? [y|n]: "
		set REQ = $<
		if (($REQ != 'y') && ($REQ != 'Y')) then
			echo "Aborted"
			exit
		endif
	endif
	chmod -R a+w UCAR_not_built_$1
	rm -R UCAR_not_built_$1
endif
mkdir UCAR_not_built_$1
cd UCAR_not_built_$1
tar -xvf ../$1.TAR.gz
if ("$1" == "WRFV3.6.1") then
	cd WRFV3/share/
	mv mediation_feedback_domain.F mediation_feedback_domain.F.distribution
	cp ../../../mediation_feedback_domain.F.fix-3.6.1 ./mediation_feedback_domain.F
	cd ../../
endif
cd ..

echo " "
echo "Creating UCAR_clean_build_$1 - a build for the ideal case em_b_wave "
echo "which generates the build-dependent files"
if ( $2 != 's') then
	echo -n "Continue? [y|n]: "
	set REQ = $<
	if (($REQ != 'y') && ($REQ != 'Y')) then
		echo "Aborted"
		exit
	endif
endif
echo "Continuing"
echo " "
if (-e UCAR_clean_build_$1) then
	echo "Deleting existing UCAR_clean_build_$1 directory structure"
	if ( $2 != 's') then
		echo -n "Continue? [y|n]: "
		set REQ = $<
		if (($REQ != 'y') && ($REQ != 'Y')) then
			echo "Aborted"
			exit
		endif
	endif
	chmod -R a+w UCAR_clean_build_$1
	rm -R UCAR_clean_build_$1
endif
mkdir UCAR_clean_build_$1
cp -R UCAR_not_built_$1/WRFV3 UCAR_clean_build_$1/
# Check that the chem directory exists - WRFV3.6.1 gives warnings if it does not
if (! -e UCAR_clean_build_$1/WRFV3/chem ) then
	mkdir UCAR_clean_build_$1/WRFV3/chem
endif
# Protect UCAR_not_built from accidental modification
chmod -R a-w UCAR_not_built_$1

cd UCAR_clean_build_$1/WRFV3/
echo " "
echo "Please configure WRF for your system.  Choose a serial configuration."
echo "Nesting is optional"
echo -n "Continue? [y|n]: "
set REQ = $<
if (($REQ != 'y') && ($REQ != 'Y')) then
	echo "Aborted"
	exit
endif
echo "Continuing"
echo " "
./configure
echo " "
echo "This script will now build the ideal case em_b_wave.  The build is logged"
echo "to compile.log.  It may take some time.  This is a standard UCAR build."
echo "A small number of warnings are expected."
if ( $2 != 's') then
	echo -n "Continue? [y|n]: "
	set REQ = $<
	if (($REQ != 'y') && ($REQ != 'Y')) then
		echo "Aborted"
		exit
	endif
endif
echo "Continuing"
echo " "
./compile em_b_wave > compile.log
if (-e main/wrf.exe) then
	echo "The build was successful"
	echo " "
	cd main
	mv wrf.exe wrf_UCAR.exe
	cd ../../..
	tools/setup_part_2.csh $1 $2
else
	echo "The build failed.  Please examine compile.log to find the problem."
	echo "Then re-run configure and compile by hand in the directory:"
	echo "$BASE_DIR/UCAR_clean_build_$1/WRFV3"
	echo "Then change directory to $BASE_DIR."
	echo "and execute tools/setup_part2.csh to complete the setup"
	echo " "
	exit
endif

# End
