#!/bin/csh -f

echo " "
echo "setup_part_2.csh"
echo " "
if (("$1" != "WRFV3.4.1") && ("$1" != "WRFV3.6.1")) then
	echo "Usage:"
	echo "$ tools/setup_part_2.csh WRFV3_version [s]"
	echo " "
	echo "Where WRFV3_version is currently WRFV3.4.1 or WRFV3.6.1"
	echo "and the optional argument s requests running silently without prompting."
	echo " "
	exit
endif

setenv BASE_DIR `pwd`

if (! -e UCAR_clean_build_$1/WRFV3/main/ideal.exe) then
	echo "This script must be run from the parent directory containing"
	echo "UCAR_clean_build_$1 after the build has run successfully."
	echo "Aborting"
	echo " "
	exit
endif

echo "We now make a run of em_b_wave to generate an output file for comparison"
if ( $2 != 's') then
	echo -n "Continue? [y|n]: "
	set REQ = $<
	if (($REQ != 'y') && ($REQ != 'Y')) then
		echo "Aborted"
		exit
	endif
endif
echo "Continuing"
echo " "
chmod -R a+w UCAR_clean_build_$1
cd UCAR_clean_build_$1/WRFV3/test/em_b_wave
./run_me_first.csh
cd ../../run
../main/ideal.exe
../main/wrf_UCAR.exe
mv wrfout_d01_0001-01-01_00\:00\:00 wrfout_$1_UCAR
cd ../../../

echo " "
echo "We now set up the directories in which the WRF files modified by fpt will be built"
if ( $2 != 's') then
	echo -n "Continue? [y|n]: "
	set REQ = $<
	if (($REQ != 'y') && ($REQ != 'Y')) then
		echo "Aborted"
		exit
	endif
endif
echo "Continuing"
echo " "

if (! -e fpt_build_environment) then
	mkdir fpt_build_environment
endif

# Set up the build environment with the unchanged UCAR files
cp -R UCAR_clean_build_$1/WRFV3 fpt_build_environment/

# check that an fpt_lib directory exists in external
if ( ! -e fpt_build_environment/WRFV3/external/fpt_lib ) then
	mkdir fpt_build_environment/WRFV3/external/fpt_lib
endif

# Protect UCAR_clean_build from accidental modification
chmod -R a-w UCAR_clean_build_$1

# Remove all of the Fortran from the build environment - they will be replaced
# in the experiments which follow
cd fpt_build_environment
../tools/clean_all_fortran.csh s

# We need to reconfigure WRF so as to include fpt_lib in the build.
cd WRFV3
cp ../../modified_build_files_$1/WRFV3/arch/* ./arch/
mv configure.wrf configure.wrf.UCAR
echo " "
echo "Please configure WRF again, using the same configuration as before"
echo "The new configuration will contain references to external/fpt_lib which is"
echo "used in some of the experiments.  The old configuration is saved in"
echo "configure.wrf.UCAR for comparison"
echo " "
if ( $2 != 's') then
	echo -n "Continue? [y|n]: "
	set REQ = $<
	if (($REQ != 'y') && ($REQ != 'Y')) then
		echo "Aborted"
		exit
	endif
endif
./configure
# We copy the new configure.wrf back to the modified_build_files directory so that
# it can be re-instated for every experiment.
cp configure.wrf ../../modified_build_files_$1/WRFV3/
cd ../..

echo " "
echo "We now set up the directories in which the modified wrf.exe will be tested"
if ( $2 != 's') then
	echo -n "Continue? [y|n]: "
	set REQ = $<
	if (($REQ != 'y') && ($REQ != 'Y')) then
		echo "Aborted"
		exit
	endif
endif
echo "Continuing"
echo " "
# Move and copy the run and test directories to create the run_tests directories
if (-e run_tests_$1) then
	chmod -R a+rw run_tests_$1
	rm -R run_tests_$1
endif
mkdir run_tests_$1
mkdir run_tests_$1/WRFV3
mkdir run_tests_$1/WRFV3/main
cp -R fpt_build_environment/WRFV3/run run_tests_$1/WRFV3/
cp -R fpt_build_environment/WRFV3/test run_tests_$1/WRFV3/
cp UCAR_clean_build_$1/WRFV3/main/wrf_UCAR.exe run_tests_$1/WRFV3/main/

# Ensure that the fpt_output directories are writable
chmod -R a+w fpt_output

echo " "
echo "The WRF fpt test environment has been set up successfully"
echo " "

# End of setup_part_2.csh


